export const BASIC_INTEGRATION = `import { NetlifyIntegration } from '@netlify/sdk'

const integration = new NetlifyIntegration();

integration.addBuildHook("onPreBuild", () => {
    console.log("Hello there.");
});

export { integration };`;
export const example = (boilerplate) => `import { NetlifyIntegration } from "@netlify/sdk";

const integration = new NetlifyIntegration();

${boilerplate.includes('build')
    ? `
integration.onEnable(async (_, { siteId, client }) => {
    // Build hooks are disabled by default, so we need to enable them
    // when the integration is enabled.
    await client.enableBuildhook(siteId);

    return {
        statusCode: 200,
    };
});

integration.addBuildHook("onPreBuild", () => {
    console.log("Hello there.");
});
`
    : ''}

${boilerplate.includes('connector')
    ? `const connector = integration.addConnector({
  typePrefix: "Example",
});

/**
 * Define your content models here.
 * https://beta--developers.netlify.app/connectors/connector-apis/#model
 */
connector.model(async ({ define }) => {
  define.nodeModel({
    name: "User",
    fields: {
      name: {
        type: "String",
        required: true,
      },
      posts: {
        type: "Post",
        list: true,
      },
    },
  });

  define.nodeModel({
    name: "Post",
    fields: {
      title: {
        type: "String",
        required: true,
      },
      blocks: {
        list: true,
        required: true,
        type: define.object({
          name: "Blocks",
          fields: {
            title: {
              type: "String",
            },
            content: {
              type: "String",
            },
          },
        }),
      },
    },
  });
});

/**
 * Fetch and store data from your API here.
 * https://beta--developers.netlify.app/connectors/connector-apis/#createallnodes
 */
connector.event("createAllNodes", ({ models }) => {
  models.User.create({
    id: "1",
    name: "Annie",
    posts: [
      {
        id: "1",
        __typename: "Post",
      },
    ],
  });

  models.Post.create({
    id: "1",
    title: "Hello World",
    blocks: [
      {
        title: "Example block title",
        content: "You can create complex content models",
      },
    ],
  });
});

/**
 * Fetch and store changed data from your API here.
 * https://beta--developers.netlify.app/connectors/connector-apis/#updatenodes
 */
connector.event("updateNodes", ({ models }) => {
  models.User.create({
    id: "1", // overwrites the existing User node with this ID
    name: "Annie",
    posts: [
      {
        id: "1",
        __typename: "Post",
      },
    ],
  });

  models.Post.create({
    id: "2", // creates a new Post since this ID doesn't exist yet
    title: "Writing lots of posts these days",
    blocks: [
      {
        title: "Page section",
        content: "what up",
      },
    ],
  });
});`
    : ''}

export { integration };
`;
export const createBasicIntegrationUI = (friendlyName) => `import { NetlifyIntegrationUI } from "@netlify/sdk";

const integrationUI = new NetlifyIntegrationUI("${friendlyName}");

const surface = integrationUI.addSurface("integrations-settings");

const root = surface.addRoute("/");

root.addText({
    value: "Welcome to the ${friendlyName} integration UI. This is where you can create your own custom UI for your integration, which will be displayed in the Netlify UI."
});

export { integrationUI };

`;
export const GITIGNORE = `
.ntli
node_modules
.cache
dev-model.gql
`;
